import { Color } from '@nativescript/core';
import { Mode } from './loading-indicator.common';
export * from './loading-indicator.common';
export class LoadingIndicator {
    show(options) {
        if (typeof options === 'undefined')
            options = {};
        if (typeof this._hud === 'undefined') {
            // use specific target, fallback to entire window
            this._targetView =
                options.ios && options.ios.view
                    ? options.ios.view
                    : this._getRootWindow();
            this._hud = MBProgressHUD.showHUDAddedToAnimated(this._targetView, true);
        }
        // ios specific
        if (options.ios && options.ios.square)
            this._hud.square = true;
        // options
        if (options.message) {
            this._hud.label.text = options.message;
            // allow line breaking
            this._hud.label.numberOfLines = 0;
        }
        if (options.progress) {
            this._hud.progress = options.progress;
        }
        if (options.mode) {
            this._hud.mode = options.mode; // casting bc we use a custom enum and not MBProgessHUD enum for mode
        }
        else {
            this._hud.mode = Mode.Indeterminate;
        }
        if (options.dimBackground) {
            this._hud.backgroundView.style = 0 /* SolidColor */;
            this._hud.backgroundView.color = new Color('#000').ios;
            this._hud.backgroundView.alpha = 0.3;
        }
        if (options.margin)
            this._hud.margin = options.margin;
        if (options.userInteractionEnabled)
            this._hud.userInteractionEnabled = options.userInteractionEnabled;
        if (options.backgroundColor) {
            this._hud.bezelView.blurEffectStyle = 4 /* Regular */;
            this._hud.bezelView.backgroundColor = new Color(options.backgroundColor).ios;
        }
        if (options.color) {
            // make activity and main label same color
            this._hud.contentColor = new Color(options.color).ios; // setting this seems to enforce coloring the activity indicator correctly
            this._hud.label.textColor = new Color(options.color).ios;
        }
        if (options.details) {
            this._hud.detailsLabel.text = options.details;
            // detail label same color with 80% opacity of that color
            // TODO: allow specific control
            this._hud.detailsLabel.textColor =
                options && options.color
                    ? new Color(options.color).ios
                    : new Color('#333').ios;
            this._hud.detailsLabel.alpha = 0.8;
        }
        if (options.hideBezel) {
            this._hud.backgroundColor = UIColor.clearColor;
            this._hud.bezelView.style = 0 /* SolidColor */;
            this._hud.bezelView.backgroundColor = UIColor.clearColor;
        }
        // handle mode setting for custom view Mode
        if (this._hud.mode &&
            this._hud.mode === Mode.CustomView && // casting to any for custom enum we map to
            options.customView) {
            if (options.customView instanceof UIImage) {
                this._hud.customView = UIImageView.alloc().initWithImage(options.customView);
            }
            else if (options.customView instanceof UIView) {
                this._hud.customView = options.customView;
            }
            else if (typeof options.customView === 'string') {
                this._hud.customView = UIImageView.alloc().initWithImage(UIImage.imageNamed(options.customView));
            }
        }
        return this._hud;
    }
    hide(targetView) {
        targetView = targetView || this._targetView || this._getRootWindow();
        MBProgressHUD.hideHUDForViewAnimated(targetView, true);
        this._hud = undefined;
    }
    _getRootWindow() {
        return UIApplication.sharedApplication.windows[0];
    }
}
//# sourceMappingURL=loading-indicator.ios.js.map